wanip
=====

Determine your WAN IP, using publicly available providers

Example usage
-------------

.. code-block:: bash

    $ wanip -h
    This is WIP...

Installation
------------

The `project <https://pypi.org/project/wanip/>`_ is on PyPI, so simply run

.. code-block:: bash

    $ python -m pip install wanip
